==> ansible_1.1+dfsg.orig.tar.gz: ansible-1.1/README.md <==
Ansible
=======

Ansible is a radically simple configuration-management, deployment, task-execution, and
multinode orchestration framework.

Read the documentation and more at http://ansible.cc

Many users run straight from the development branch (it's generally fine to do so), but you might also wish to consume a release.  You can find 
instructions on http://ansible.cc/docs/gettingstarted.html for a variety of platforms.  If you want a tarball of the last release, go to 
http://ansible.cc/releases/ and you can also install with pip (though that will bring in some optional binary dependencies you normally do not need).

Design Principles
=================

   * Dead simple setup
   * Super fast & parallel by default
   * No server or client daemons; use existing SSHd
   * No additional software required on client boxes
   * Modules can be written in ANY language
   * Awesome API for creating very powerful distributed scripts
   * Be usable as non-root
   * The easiest config management system to use, ever.

Get Involved
============

   * [ansible-project mailing list](http://groups.google.com/group/ansible-project)
   * irc.freenode.net: #ansible

Branch Info
===========

   * Releases are named after Van Halen songs.
   * The devel branch corresponds to the release actively under development.
   * Various release-X.Y branches exist for previous releases
   * We'd love to have your contributions, read "CONTRIBUTING.md" for process notes.

Author
======

Michael DeHaan -- michael.dehaan@gmail.com

[http://michaeldehaan.net](http://michaeldehaan.net/)

==> ansible-1.3.2.tar.gz: ansible-1.3.2/README.md <==
Ansible
=======

Ansible is a radically simple configuration-management, deployment, task-execution, and
multinode orchestration framework.

Read the documentation and more at http://ansibleworks.com/

Many users run straight from the development branch (it's generally fine to do so), but you might also wish to consume a release.  You can find 
instructions on http://ansibleworks.com/docs/gettingstarted.html for a variety of platforms.  If you want a tarball of the last release, go to 
http://ansibleworks.com/releases/ and you can also install with pip (though that will bring in some optional binary dependencies you normally do not need).

Design Principles
=================

   * Dead simple setup
   * Super fast & parallel by default
   * No server or client daemons; use existing SSHd
   * No additional software required on client boxes
   * Modules can be written in ANY language
   * Awesome API for creating very powerful distributed scripts
   * Be usable as non-root
   * The easiest config management system to use, ever.

Get Involved
============

   * [ansible-project mailing list](http://groups.google.com/group/ansible-project), rss: [here](https://groups.google.com/group/ansible-project/feed/rss_v2_0_msgs.xml?num=50&pli=1)
   * irc.freenode.net: #ansible

Branch Info
===========

   * Releases are named after Van Halen songs.
   * The devel branch corresponds to the release actively under development.
   * Various release-X.Y branches exist for previous releases
   * We'd love to have your contributions, read "CONTRIBUTING.md" for process notes.

Author
======

Michael DeHaan -- michael@ansibleworks.com

[AnsibleWorks](http://ansibleworks.com)
